

# Calculix frd converter
Works on binary FRD files written using the *\*element output* and *\*node output* commands. 

## Installation
```bash
pip install frd2vtu
```

## Usage
```bash
frd2vtu input1.frd input2.frd ... 
```

## Test
```bash
cd test
bash test.sh
```
